
// The following ifdef block is the standard way of creating macros which make exporting 
// from a DLL simpler. All files within this DLL are compiled with the SURF_EXPORTS
// symbol defined on the command line. This symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see 
// SURF_API functions as being imported from a DLL, whereas this DLL sees symbols
// defined with this macro as being exported.
#ifdef SURF_EXPORTS
#define SURF_API __declspec(dllexport)
#else
#define SURF_API __declspec(dllimport)
#endif


/*
The following functions are used during the raytrace when a Surface Property
is applied to a surface.
*/

// Function address for TracePro random number generator
typedef double (*RAND_FN)(void);
RAND_FN random_function;


// Initialization function will pass in the address of the TracePro 
// random number generator. Any other initialization is done here.
// This routine is called after the Dll is loaded by TracePro
SURF_API double fnInitDll(RAND_FN address);


// During the raytrace, TracePro will evaluate the specular terms
//     of the surface property. 
//
// This function will be given the following inputs
//     In Input Array			(double *)	wavelength,
//											temperature,
//											position X,
//											position Y,
//											position Z,
//											incident direction X,
//											incident direction Y,
//											incident direction Z,
//											flux S0, (Stokes Vector)
//											flux S1, (Stokes Vector)
//											flux S2, (Stokes Vector)
//											flux S3, (Stokes Vector)
//											flux SX, (Stokes Vector)
//											flux SY, (Stokes Vector)
//											flux SZ, (Stokes Vector)
//											surface normal X,
//											surface normal Y,
//											surface normal Z,
//     In User Array			(double *)
//        Not used
//
// The function must then return an array containing Absorption, Reflection, 
// Transmission and Phase for the surface in a single array
//        Results				(double *)	s - absorptance,
// 											p - absorptance,
// 											s - reflectance,
//											p - reflectance,
// 											s - transmittance,
// 											p - transmittance,
// 											Phase reflection (deg),
//											Phase transmission (deg)
SURF_API double fnEvaluateCoating(
								  double*	input,
								  int		input_size,
								  double*	user,
								  int		user_size,
								  double*	results,
								  int		results_size
								  );
